@@ -164,9 +164,17 @@ class Gnuplot(object):
         for v in args:
             #print('set %s' %(v))
             self.__call__('set %s' %(v))
-        for k, v in kwargs.items():
+        # kwargs input:
+        for k,v in kwargs.items():
             #print('set %s %s' %(k, v))
-            self.__call__('set %s %s' %(k, v))
+            #self.set(**kwargs)
+            if isinstance(v, list):
+                for i in v:
+                    #print('i,v: set %s %s' %(k, i))
+                    self.__call__('set %s %s' %(k, i))
+            else:
+                #print('k,v: set %s %s' %(k, v))
+                self.__call__('set %s %s' %(k, v))
 
     def unset(self, *items):
         for item in items:
@@ -178,7 +186,14 @@ class Gnuplot(object):
     def plot(self, *items, **kwargs):
         for k,v in kwargs.items():
             #print('set %s %s' %(k, v))
-            self.set(**kwargs)
+            #self.set(**kwargs)
+            if isinstance(v, list):
+                for i in v:
+                    #print('set %s %s' %(k, i))
+                    self.__call__('set %s %s' %(k, i))
+            else:
+                #print('set %s %s' %(k, v))
+                self.__call__('set %s %s' %(k, v))
 
         c = 'plot'
         for item in items:
@@ -194,8 +209,21 @@ class Gnuplot(object):
     #    cmd = c.rstrip(',')
     #    self.__call__(cmd + '\n')
 
-    def splot(self, *items):
+    def splot(self, *items, **kwargs):
         c = 'splot'
+
+        # kwargs input:
+        for k,v in kwargs.items():
+            #print('set %s %s' %(k, v))
+            #self.set(**kwargs)
+            if isinstance(v, list):
+                for i in v:
+                    #print('set %s %s' %(k, i))
+                    self.__call__('set %s %s' %(k, i))
+            else:
+                #print('set %s %s' %(k, v))
+                self.__call__('set %s %s' %(k, v))
+
         for item in items:
             c = c + " " + item + ","
         cmd = c.rstrip(',')
